@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2015-12-28'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2016-02-26'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -19,16 +19,18 @@ has name => (is=>'rw');
 has url  => (is=>'rw');
 has _pa => (is=>'rw');
 has parent => (is=>'rw'); # points fo Perinci::To::* object
-has export => (is=>'rw', default=>0); # 0=not exported by default but exportable, 1=exported by default, -1=never export
+has export => (is=>'rw', default=>undef); # undef=unknown, 0=not exported by default but exportable, 1=exported by default, -1=never export
 
 sub BUILD {
     my ($self, $args) = @_;
 
     $args->{meta} or die "Please specify meta";
 
-    my $pdres = $self->{parent}{_doc_res};
+    my $parent = $self->{parent};
+    my $pdres  = $self->{parent}{_doc_res};
 
-    if (@{ $pdres->{function_names_by_meta_addr}{"$args->{meta}"} } > 1) {
+    if ($pdres &&
+            @{ $pdres->{function_names_by_meta_addr}{"$args->{meta}"} } > 1) {
         # function is an alias to another function, no need to duplicate
         # documenting the function, just mention that this function is alias to
         # another.
@@ -224,7 +226,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.74 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-12-28.
+This document describes version 0.75 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2016-02-26.
 
 =for Pod::Coverage .+
 
@@ -234,7 +236,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
@@ -250,7 +252,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
