@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-12-28'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2016-02-26'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -48,7 +48,7 @@ sub after_gen_doc {
     {
         my $pdres = $self->parent->{_doc_res};
         my $fnames = $pdres->{function_names_by_meta_addr}{"$orig_meta"};
-        if (@$fnames > 1) {
+        if ($fnames && @$fnames > 1) {
             $self->add_doc_lines(
                 __("Alias for") . " C<$fnames->[0]>.",
                 "",
@@ -158,7 +158,13 @@ sub after_gen_doc {
                     $log->debugf("Example does not provide args/argv, skipped trying to get result from calling function");
                     last GET_RESULT;
                 }
-                $res = $self->{_pa}->request(call => $self->{url}, \%extra);
+                my $url;
+                if ($self->{url} =~ /\A\w+\z/) {
+                    $url = $self->parent->name . $self->{url};
+                } else {
+                    $url = $self->{url};
+                }
+                $res = $self->{_pa}->request(call => $url, \%extra);
                 unless ($orig_result_naked) {
                     $tff = $res->[3]{'table.fields'};
                 }
@@ -225,8 +231,10 @@ sub after_gen_doc {
         if $dres->{description};
 
     {
-        my $export = $self->{export} // 0;
-        if ($export == 0) {
+        my $export = $self->{export};
+        if (!defined($export)) {
+            # unknown
+        } elsif ($export == 0) {
             $self->add_doc_lines(__("This function is not exported by default, but exportable."), "");
         } elsif ($export == 1) {
             $self->add_doc_lines(__("This function is exported by default."), "");
@@ -398,7 +406,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.74 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-12-28.
+This document describes version 0.75 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-02-26.
 
 =head1 SYNOPSIS
 
@@ -410,17 +418,13 @@ You can use the included L<peri-doc> script, or:
 
 =for Pod::Coverage .+
 
-=head1 SEE ALSO
-
-L<Perinci::To::POD> to generate POD documentation for the whole package.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To-Doc>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
@@ -430,13 +434,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::To::POD> to generate POD documentation for the whole package.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
